# Fabric CICD

[![Language](https://img.shields.io/badge/language-Python-blue.svg)](https://www.python.org/)
[![PyPi version](https://badgen.net/pypi/v/fabric-cicd/)](https://pypi.org/project/fabric-cicd)
[![Code style: ruff](https://img.shields.io/badge/code%20style-ruff-000000.svg)](https://github.com/charliermarsh/ruff)

---

## Project Overview

fabric-cicd is a Python library designed for use with [Microsoft Fabric](https://learn.microsoft.com/en-us/fabric/) workspaces. This library supports code-first Continuous Integration / Continuous Deployment (CI/CD) automations to seamlessly integrate Source Controlled workspaces into a deployment framework. The goal is to assist CI/CD developers who prefer not to interact directly with the Microsoft Fabric APIs.

## Documentation

All documentation is hosted on our [fabric-cicd](https://microsoft.github.io/fabric-cicd/) GitHub Pages

Section Overview:

-   [Home](https://microsoft.github.io/fabric-cicd/latest/)
-   [How To](https://microsoft.github.io/fabric-cicd/latest/how_to/)
-   [Contribution](https://microsoft.github.io/fabric-cicd/latest/contribution/)
-   [Changelog](https://microsoft.github.io/fabric-cicd/latest/changelog/)
-   [About](https://microsoft.github.io/fabric-cicd/latest/help/) - Inclusive of Support & Security Policies

## Installation

To install fabric-cicd, run:

```bash
pip install fabric-cicd
```

## Trademarks

This project may contain trademarks or logos for projects, products, or services. Authorized use of Microsoft trademarks or logos is subject to and must follow [Microsoft's Trademark & Brand Guidelines](https://www.microsoft.com/en-us/legal/intellectualproperty/trademarks/usage/general). Use of Microsoft trademarks or logos in modified versions of this project must not cause confusion or imply Microsoft sponsorship. Any use of third-party trademarks or logos are subject to those third-party's policies.
